# Table of Contents

- [automation-examples-selected-use-cases](<./automation-examples-selected-use-cases.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Automations Best Practices: Selected Use Cases](<./Automations-Best-Practices-Selected-Use-Cases.md>)
  - [Setting the Quality Seal upon Completing a Survey](<./Automations-Best-Practices-Selected-Use-Cases/Setting-the-Quality-Seal-upon-Completing-a-Survey.md>)
  - [Setting the Quality Seal upon Completing a To-Do](<./Automations-Best-Practices-Selected-Use-Cases/Setting-the-Quality-Seal-upon-Completing-a-To-Do.md>)
  - [Assigning To-Dos Created by Automations to Teams](<./Automations-Best-Practices-Selected-Use-Cases/Assigning-To-Dos-Created-by-Automations-to-Teams.md>)
  - [Concatenating To-Dos Sequentially](<./Automations-Best-Practices-Selected-Use-Cases/Concatenating-To-Dos-Sequentially.md>)
  - [Assigning the TIME Classification Value Based on the Functional and Technical Fit](<./Automations-Best-Practices-Selected-Use-Cases/Assigning-the-TIME-Classification-Value-Based-on-the-Functional-and-Technical-Fit.md>)
